# streamlit_3dmol
This project aims to provide an easy way to create a web app for interacting with molecular structures using Streamlit. 
Currently sub0.py is simply a static component call to 3Dmol.js by means of  component.html(), but the implementation of a bi-directional component seems to be straightforward.

You must first install streamlit :
<p>
$ pip install streamlit

Then you can run
$ streamlit run sub0.py

<p>
 You will get something like this: 

![GitHub Logo](https://github.com/napoles-uach/figuras/blob/master/Captura%20de%20pantalla%202020-07-29%20a%20la(s)%2013.24.04.png)

